..
    Copyright (C) 2023 Graz University of Technology.

    invenio-records-global-search is free software; you can redistribute it
    and/or modify it under the terms of the MIT License; see LICENSE file for
    more details.

Changes
=======

Version v0.3.0 (release 2024-06-12)

- global: rely on finalize_app
- schema: allow empty rights.
  the license setting is not mondatory on the different datamodels
  therefore it can't be required on the global search



Version v0.2.3 (release 2024-02-14)

- search: change to rdm multi style
- fix: update should be allowed
- ruff: fix noqa v0.1.14


Version v0.2.2 (release 2024-01-07)

- fix: add missing permission


Version v0.2.1 (release 2023-11-23)

- translations: update
- facets: implement better wording for datamodel


Version v0.2.0 (release 2023-11-09)




Version v0.1.0 (release 2023-11-09)



